/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_YY_EXPR_YACC_HH_INCLUDED
# define YY_YY_EXPR_YACC_HH_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    CONSTANT = 258,
    VARIABLE = 259,
    FUNCTION = 260,
    QUESTION = 261,
    COLON = 262,
    REMOVE = 263,
    PRINT = 264,
    AND = 265,
    OR = 266,
    LEG = 267,
    GE = 268,
    LE = 269,
    EQ = 270,
    NE = 271,
    GT = 272,
    LT = 273,
    UMINUS = 274
  };
#endif
/* Tokens.  */
#define CONSTANT 258
#define VARIABLE 259
#define FUNCTION 260
#define QUESTION 261
#define COLON 262
#define REMOVE 263
#define PRINT 264
#define AND 265
#define OR 266
#define LEG 267
#define GE 268
#define LE 269
#define EQ 270
#define NE 271
#define GT 272
#define LT 273
#define UMINUS 274

/* Value type.  */



int yyparse (parse_param_t *parse_arg, void *scanner);

#endif /* !YY_YY_EXPR_YACC_HH_INCLUDED  */
